#
# spec file for package python-swifter
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-swifter
Version:        1.4.0
Release:        1.4
Summary:        Tool to speed up pandas calculations
License:        MIT
URL:            https://github.com/jmcarpenter2/swifter
Source:         https://github.com/jmcarpenter2/swifter/archive/%{version}.tar.gz#/swifter-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-dask-dataframe >= 2.10.0
Requires:       python-pandas >= 1.0
Requires:       python-psutil >= 5.6.6
Requires:       python-tqdm >= 4.33.0
Suggests:       python-ipywidgets >= 7.0.0
Suggests:       python-ray >= 1.0
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module dask-dataframe >= 2.10.0}
BuildRequires:  %{python_module ipywidgets >= 7.0.0}
BuildRequires:  %{python_module pandas >= 1.0}
BuildRequires:  %{python_module psutil >= 5.6.6}
BuildRequires:  %{python_module pytest-xdist}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module tqdm >= 4.33.0}
# /SECTION
%python_subpackages

%description
A package which efficiently applies any function to a
pandas dataframe or series in the fastest available manner

%prep
%setup -q -n swifter-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# we fail the speedtests on the build service machines. Disable that portion of the tests
sed -i 's/if self.ncores > 1:  # speed test/if False: # no speed test/' swifter/swifter_tests.py
# groupy requires the extra dep python-ray, which is not available
donttest="(TestPandasDataFrame and groupby)"
# wrong axis parameter
donttest="$donttest or test_nonvectorized_math_apply_on_small_dataframe"
%pytest -n auto swifter/swifter_tests.py -k "not ($donttest)"

%files %{python_files}
%doc README.md
%license LICENSE
%{python_sitelib}/swifter
%{python_sitelib}/swifter-%{version}*-info

%changelog
* Tue Aug  1 2023 Markéta Machová <mmachova@suse.com>
- Update to 1.4.0
  * Significantly reduced core dependencies of swifter library.
  * Removed deprecated loffset parameter
  * Updated README to be more readable for darkmode users
* Fri Jun  2 2023 Steve Kowalik <steven.kowalik@suse.com>
- Stop skipping Python 3.11.
* Sat Mar 25 2023 Ben Greiner <code@bnavigator.de>
- Update to 1.3.4
  * Enable indexing after a groupby, e.g.
    df.swifter.groupby(by)[key].apply(func)
  * Improve groupby apply progress bar
  * Previously, the groupby apply progress bar only appeared after
    the data was distributed across the cores.
  * Now, the groupby apply progress bar appears before the data is
    distributed for a more realistic reflection of how long it took
  * Additional groupby apply code refactoring and optimizations,
    including removing the mutability of the data within ray
- Version 1.3.3
  * Enable users to pass in df.index as the by parameter for the
    df.swifter.groupby(by).apply(func) command
- Version 1.3.2
  * Enable users to df.swifter.groupby.apply, which requires a new
    package (ray) that now available as an extra_requires.
  * To use groupby apply, install swifter as pip install -U
    swifter[groupby]
  * All credit goes to user @diditforlulz273 for writing the
    performant groupby apply code, that is now part of swifter!
- Version 1.2.0
  * Enable users to force_parallel which immediately forces swifter
    to jump to using dask apply. This enables a simple interface
    for parallel processing, but disables swifter's algorithm to
    determine the fastest apply solution possible.
- Version 1.1.4
  * Enable users to leverage set_defaults functionality so they
    don't have to keep invoking individual settings on a per
    swifter invocation basis
- Version 1.1.3
  * Enhance the robustness of swifter by randomizing the sample
    index to avoid sparse data impacting the validity of apply
    validation
  * Resolve issue where functions that return a non array-like
    cause swifter to fail on vectorization
* Sun Mar 27 2022 Ben Greiner <code@bnavigator.de>
- Update to 1.1.2
  * Resolve installation issue by removing import from setup.py
- Reenable python310 build, now that dask is available
* Mon Feb  7 2022 Ben Greiner <code@bnavigator.de>
- Update to 1.1.1
  * Resolve installation issues by removing modin dependency, and
    modin apply route for axis=1 string applies
  * apply_dask_on_strings returns to original functionality, which
    allows control over whether to use dask or pandas by default
    for string applies
  * Sample applies now suppress logging in addition to stdout and
    stderr
  * Allow new kwargs offset and origin for pandas df.resample
- Require and BuildRequire everything that is declared in the
  setuptools metadata in order to avoid possible pkg_resources
  failures
- Skip python310 due to python310-dask not available yet
* Sun Feb 21 2021 Ben Greiner <code@bnavigator.de>
- Skip python36 build: With NumPy 1.20, python36-numpy is no
  longer available in Tumbleweed (NEP 29)
* Tue Feb  9 2021 Ben Greiner <code@bnavigator.de>
- Update to 1.0.7
  * Sample applies now suppress logging in addition to stdout and
    stderr
  * Allow new kwargs offset and origin for pandas df.resample
- Changes in 1.0.5
  * Added warnings/errors for swifter methods which do not exist
    when using modin dataframes
  * Updated Dask Dataframe dependencies to require a more recent
    version
  * Updated examples/speed benchmark notebooks
- Changes in 1.0.3
  * Fixed bug with string, axis=1 applies for pandas dataframes
    that prevented swifter from leveraging modin for
    parallelization when returning a series instead of a dataframe
- Changes in 1.0.2
  * Remove pickle5 hard dependency
- Changes in 1.0.1
  * Reduce resources consumed by swifter by only importing modin/
    ray when necessary.
  * Added swifter.register_modin() function, which gives access to
    modin.DataFrame.swifter.apply(...), but is only required if
    modin is imported after swifter. If you import modin before
    swifter, this is not necessary.
- Changes in 1.0.0
  * Two major enhancements are included in this release, both
    involving the use of modin in swifter. Special thanks to Devin
    Petersohn for the collaboration.
  * Enable compatibility with modin dataframes. Compatibility not
    only allows modin dataframes to work with
    df.swifter.apply(...), but still attempts to vectorize the
    operation which can lead to a performance boost.
    Example:
    import modin.pandas as pd
    df = pd.DataFrame(...)
    df.swifter.apply(...)
  * Significantly speed up swifter axis=1 string applies by using
    Modin, resolving a long-standing issue for swifter.
  * Use Modin for axis=1 string applies, unless
    allow_dask_on_strings(True) is set. If that flag is set, still
    use Dask.
    NOTE: this means that allow_dask_on_strings() is no longer
    required to work with text data using swifter.
- Changes in 0.305
  * Remove Numba hard dependency, but still handle TypingErrors
    when numba is installed
  * Only call tqdm's progress_apply on transformations (e.g.
    Resampler, Rolling) when tqdm has an implementation for that
    object.
- Do not require modin and skip the tests involving it.
  gh#jmcarpenter2/swifter#147
* Thu May  7 2020 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.304:
  * Various fixes for updated dependencies
* Mon Feb 10 2020 Todd R <toddrme2178@gmail.com>
- Update to 0.301
  * Following pandas release v1.0.0, removing deprecated keyword args "broadcast" and "reduce"
* Thu Jan 30 2020 Todd R <toddrme2178@gmail.com>
- Update to 0.300
  * Added new applymap method for pandas dataframes.
    df.swifter.applymap(...)
- Update to 0.297
  * Fixed issue causing errors when using swifter on empty
    dataframes. Now swifter will perform a pandas apply on empty
    dataframes.
- Drop upstream-included use_current_exe.patch
* Tue Nov 26 2019 Todd R <toddrme2178@gmail.com>
- Initial version
- Add use_current_exe.patch
  See https://github.com/jmcarpenter2/swifter/pull/92
